@@ -53,7 +53,7 @@
 #define ARROW_ENABLE_THREADING
 /* #undef ARROW_GCS */
 #define ARROW_HDFS
-/* #undef ARROW_S3 */
+#define ARROW_S3
 #define ARROW_USE_GLOG
 #define ARROW_USE_NATIVE_INT128
 #define ARROW_WITH_BROTLI
